import common_models_pb2 as _common_models_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AOICollection(_message.Message):
    __slots__ = ("id", "name", "created_on", "user_id", "num_aois")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    NUM_AOIS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_on: _timestamp_pb2.Timestamp
    user_id: str
    num_aois: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., user_id: _Optional[str] = ..., num_aois: _Optional[int] = ...) -> None: ...

class AOIInfo(_message.Message):
    __slots__ = ("aoi_id", "aoi_version_id", "aoi_name", "lat", "long", "area_km2", "geom", "timezone")
    AOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_NAME_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LONG_FIELD_NUMBER: _ClassVar[int]
    AREA_KM2_FIELD_NUMBER: _ClassVar[int]
    GEOM_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    aoi_id: str
    aoi_version_id: str
    aoi_name: str
    lat: float
    long: float
    area_km2: float
    geom: str
    timezone: str
    def __init__(self, aoi_id: _Optional[str] = ..., aoi_version_id: _Optional[str] = ..., aoi_name: _Optional[str] = ..., lat: _Optional[float] = ..., long: _Optional[float] = ..., area_km2: _Optional[float] = ..., geom: _Optional[str] = ..., timezone: _Optional[str] = ...) -> None: ...

class AOICollectionCreateRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class AOICollectionCreateResponse(_message.Message):
    __slots__ = ("status_code", "aoi_collection")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_collection: AOICollection
    def __init__(self, status_code: _Optional[int] = ..., aoi_collection: _Optional[_Union[AOICollection, _Mapping]] = ...) -> None: ...

class AOICollectionGetRequest(_message.Message):
    __slots__ = ("id", "verbose", "pagination")
    ID_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: str
    verbose: bool
    pagination: _common_models_pb2.Pagination
    def __init__(self, id: _Optional[str] = ..., verbose: bool = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AOICollectionGetResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_info")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_INFO_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2.Pagination
    aoi_info: _containers.RepeatedCompositeFieldContainer[AOIInfo]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., aoi_info: _Optional[_Iterable[_Union[AOIInfo, _Mapping]]] = ...) -> None: ...

class AOICollectionAddRequest(_message.Message):
    __slots__ = ("id", "aoi_version_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSION_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    aoi_version_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, id: _Optional[str] = ..., aoi_version_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class AOICollectionAddResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AOICollectionRemoveRequest(_message.Message):
    __slots__ = ("id", "aoi_version_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    AOI_VERSION_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    aoi_version_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, id: _Optional[str] = ..., aoi_version_ids: _Optional[_Iterable[int]] = ...) -> None: ...

class AOICollectionRemoveResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AOICollectionCloneRequest(_message.Message):
    __slots__ = ("id", "name")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class AOICollectionCloneResponse(_message.Message):
    __slots__ = ("status_code", "aoi_collection_id")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    aoi_collection_id: str
    def __init__(self, status_code: _Optional[int] = ..., aoi_collection_id: _Optional[str] = ...) -> None: ...

class AOICollectionListRequest(_message.Message):
    __slots__ = ("pagination", "min_created_on", "max_created_on", "search_text")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    MIN_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    min_created_on: _timestamp_pb2.Timestamp
    max_created_on: _timestamp_pb2.Timestamp
    search_text: str
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., min_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., search_text: _Optional[str] = ...) -> None: ...

class AOICollectionListResponse(_message.Message):
    __slots__ = ("status_code", "pagination", "aoi_collections")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTIONS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    pagination: _common_models_pb2.Pagination
    aoi_collections: _containers.RepeatedCompositeFieldContainer[AOICollection]
    def __init__(self, status_code: _Optional[int] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., aoi_collections: _Optional[_Iterable[_Union[AOICollection, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: token.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'token.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btoken.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"C\n\x12TokenCreateRequest\x12\x18\n\x10\x64uration_minutes\x18\x01 \x01(\x05\x12\x13\n\x0b\x66or_user_id\x18\x02 \x01(\t\"=\n\x13TokenCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t2O\n\x08TokenApi\x12\x43\n\x06\x63reate\x12\x1b.oi.papi.TokenCreateRequest\x1a\x1c.oi.papi.TokenCreateResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'token_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TOKENCREATEREQUEST']._serialized_start=45
  _globals['_TOKENCREATEREQUEST']._serialized_end=112
  _globals['_TOKENCREATERESPONSE']._serialized_start=114
  _globals['_TOKENCREATERESPONSE']._serialized_end=175
  _globals['_TOKENAPI']._serialized_start=177
  _globals['_TOKENAPI']._serialized_end=256
# @@protoc_insertion_point(module_scope)



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataType(_message.Message):
    __slots__ = ("name", "description", "schema", "data_source_ids", "sensor_type", "query_schema")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_IDS_FIELD_NUMBER: _ClassVar[int]
    SENSOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    QUERY_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    schema: str
    data_source_ids: _containers.RepeatedScalarFieldContainer[str]
    sensor_type: str
    query_schema: _struct_pb2.Struct
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., schema: _Optional[str] = ..., data_source_ids: _Optional[_Iterable[str]] = ..., sensor_type: _Optional[str] = ..., query_schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DataTypeCreateRequest(_message.Message):
    __slots__ = ("name", "description", "schema", "sensor_type", "query_schema")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    SENSOR_TYPE_FIELD_NUMBER: _ClassVar[int]
    QUERY_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    schema: str
    sensor_type: str
    query_schema: _struct_pb2.Struct
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., schema: _Optional[str] = ..., sensor_type: _Optional[str] = ..., query_schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DataTypeCreateResponse(_message.Message):
    __slots__ = ("status_code", "data_type")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    data_type: DataType
    def __init__(self, status_code: _Optional[int] = ..., data_type: _Optional[_Union[DataType, _Mapping]] = ...) -> None: ...

class DataTypeGetRequest(_message.Message):
    __slots__ = ("names",)
    NAMES_FIELD_NUMBER: _ClassVar[int]
    names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, names: _Optional[_Iterable[str]] = ...) -> None: ...

class DataTypeGetResponse(_message.Message):
    __slots__ = ("status_code", "data_types")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    data_types: _containers.RepeatedCompositeFieldContainer[DataType]
    def __init__(self, status_code: _Optional[int] = ..., data_types: _Optional[_Iterable[_Union[DataType, _Mapping]]] = ...) -> None: ...

class DataTypeListRequest(_message.Message):
    __slots__ = ("search_text",)
    SEARCH_TEXT_FIELD_NUMBER: _ClassVar[int]
    search_text: str
    def __init__(self, search_text: _Optional[str] = ...) -> None: ...

class DataTypeListResponse(_message.Message):
    __slots__ = ("status_code", "data_types")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPES_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    data_types: _containers.RepeatedCompositeFieldContainer[DataType]
    def __init__(self, status_code: _Optional[int] = ..., data_types: _Optional[_Iterable[_Union[DataType, _Mapping]]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import struct_pb2 as _struct_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class AlgorithmComputationExecution(_message.Message):
    __slots__ = ("id", "computation_id", "start_ts", "finish_ts", "partial_results", "status", "created_on", "validation_details", "input_ids")
    class AlgorithmComputationExecutionStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        NEW: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        PERMISSION_CHECKING: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        PERMISSION_CHECK_SUCCEEDED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        PERMISSION_CHECK_FAILED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        VALIDATING: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        VALIDATION_SUCCEEDED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        VALIDATION_FAILED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        RUNNING: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        SUCCEEDED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        FAILED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        STOPPED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        CANCELLED: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
        RETRYING: _ClassVar[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus]
    UNKNOWN: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    NEW: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    PERMISSION_CHECKING: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    PERMISSION_CHECK_SUCCEEDED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    PERMISSION_CHECK_FAILED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    VALIDATING: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    VALIDATION_SUCCEEDED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    VALIDATION_FAILED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    RUNNING: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    SUCCEEDED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    FAILED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    STOPPED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    CANCELLED: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    RETRYING: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    ID_FIELD_NUMBER: _ClassVar[int]
    COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    START_TS_FIELD_NUMBER: _ClassVar[int]
    FINISH_TS_FIELD_NUMBER: _ClassVar[int]
    PARTIAL_RESULTS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_DETAILS_FIELD_NUMBER: _ClassVar[int]
    INPUT_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    computation_id: str
    start_ts: _timestamp_pb2.Timestamp
    finish_ts: _timestamp_pb2.Timestamp
    partial_results: bool
    status: AlgorithmComputationExecution.AlgorithmComputationExecutionStatus
    created_on: _timestamp_pb2.Timestamp
    validation_details: _struct_pb2.Struct
    input_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., computation_id: _Optional[str] = ..., start_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., finish_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., partial_results: bool = ..., status: _Optional[_Union[AlgorithmComputationExecution.AlgorithmComputationExecutionStatus, str]] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., validation_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., input_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AlgorithmComputationExecutionGetRequest(_message.Message):
    __slots__ = ("ids", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class AlgorithmComputationExecutionGetResponse(_message.Message):
    __slots__ = ("status_code", "algorithm_computation_executions", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_EXECUTIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    algorithm_computation_executions: _containers.RepeatedCompositeFieldContainer[AlgorithmComputationExecution]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., algorithm_computation_executions: _Optional[_Iterable[_Union[AlgorithmComputationExecution, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: analysis_version.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'analysis_version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_pb2 as analysis__pb2
try:
  common__models__pb2 = analysis__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__pb2.common_models_pb2
from terrascope_api.models import algorithm_version_pb2 as algorithm__version__pb2
try:
  common__models__pb2 = algorithm__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__version__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__version__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__version__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__version__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__version__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_pb2 import *
from terrascope_api.models.algorithm_version_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61nalysis_version.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0e\x61nalysis.proto\x1a\x17\x61lgorithm_version.proto\"\xdb\x01\n\x10\x41nalysisManifest\x12\x18\n\x10manifest_version\x18\x01 \x01(\t\x12\x34\n\x08metadata\x18\x02 \x01(\x0b\x32\".oi.papi.AnalysisManifest.Metadata\x12\x37\n\x0f\x61lgorithm_nodes\x18\x03 \x03(\x0b\x32\x1e.oi.papi.AnalysisAlgorithmNode\x1a>\n\x08Metadata\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"\xdf\x01\n\x0f\x41nalysisVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x08\x61nalysis\x18\x02 \x01(\x0b\x32\x11.oi.papi.Analysis\x12\x34\n\x11\x61nalysis_manifest\x18\x03 \x01(\x0b\x32\x19.oi.papi.AnalysisManifest\x12.\n\ncreated_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12\x61lgorithm_versions\x18\x05 \x03(\x0b\x32\x19.oi.papi.AlgorithmVersion\"i\n\x1c\x41nalysisVersionCreateRequest\x12\x13\n\x0b\x61nalysis_id\x18\x01 \x01(\t\x12\x34\n\x11\x61nalysis_manifest\x18\x02 \x01(\x0b\x32\x19.oi.papi.AnalysisManifest\"h\n\x1d\x41nalysisVersionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x32\n\x10\x61nalysis_version\x18\x02 \x01(\x0b\x32\x18.oi.papi.AnalysisVersion\"\x8e\x01\n\x19\x41nalysisVersionGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x18\n\x10include_manifest\x18\x02 \x01(\x08\x12!\n\x19include_algorithm_details\x18\x03 \x01(\x08\x12\'\n\npagination\x18\x04 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x8f\x01\n\x1a\x41nalysisVersionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x33\n\x11\x61nalysis_versions\x18\x02 \x03(\x0b\x32\x18.oi.papi.AnalysisVersion\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x9c\x02\n\x1a\x41nalysisVersionListRequest\x12\x13\n\x0b\x61nalysis_id\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x13\n\x0bsearch_text\x18\x03 \x01(\t\x12\x32\n\x0emin_created_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10include_manifest\x18\x06 \x01(\x08\x12\x1c\n\x14include_all_versions\x18\x07 \x01(\x08\x12\'\n\npagination\x18\x08 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x90\x01\n\x1b\x41nalysisVersionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x33\n\x11\x61nalysis_versions\x18\x02 \x03(\x0b\x32\x18.oi.papi.AnalysisVersion\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x90\x02\n\x12\x41nalysisVersionApi\x12W\n\x06\x63reate\x12%.oi.papi.AnalysisVersionCreateRequest\x1a&.oi.papi.AnalysisVersionCreateResponse\x12N\n\x03get\x12\".oi.papi.AnalysisVersionGetRequest\x1a#.oi.papi.AnalysisVersionGetResponse\x12Q\n\x04list\x12#.oi.papi.AnalysisVersionListRequest\x1a$.oi.papi.AnalysisVersionListResponseP\x01P\x02P\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analysis_version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYSISMANIFEST']._serialized_start=131
  _globals['_ANALYSISMANIFEST']._serialized_end=350
  _globals['_ANALYSISMANIFEST_METADATA']._serialized_start=288
  _globals['_ANALYSISMANIFEST_METADATA']._serialized_end=350
  _globals['_ANALYSISVERSION']._serialized_start=353
  _globals['_ANALYSISVERSION']._serialized_end=576
  _globals['_ANALYSISVERSIONCREATEREQUEST']._serialized_start=578
  _globals['_ANALYSISVERSIONCREATEREQUEST']._serialized_end=683
  _globals['_ANALYSISVERSIONCREATERESPONSE']._serialized_start=685
  _globals['_ANALYSISVERSIONCREATERESPONSE']._serialized_end=789
  _globals['_ANALYSISVERSIONGETREQUEST']._serialized_start=792
  _globals['_ANALYSISVERSIONGETREQUEST']._serialized_end=934
  _globals['_ANALYSISVERSIONGETRESPONSE']._serialized_start=937
  _globals['_ANALYSISVERSIONGETRESPONSE']._serialized_end=1080
  _globals['_ANALYSISVERSIONLISTREQUEST']._serialized_start=1083
  _globals['_ANALYSISVERSIONLISTREQUEST']._serialized_end=1367
  _globals['_ANALYSISVERSIONLISTRESPONSE']._serialized_start=1370
  _globals['_ANALYSISVERSIONLISTRESPONSE']._serialized_end=1514
  _globals['_ANALYSISVERSIONAPI']._serialized_start=1517
  _globals['_ANALYSISVERSIONAPI']._serialized_end=1789
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_tracking.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_tracking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x64\x61ta_tracking.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"T\n\x05Links\x12\x0c\n\x04href\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03rel\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\r\n\x05title\x18\x05 \x01(\t\"7\n\tParentRef\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\"\xd5\x01\n\x0cTrackedEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61ta_tracking_id\x18\x02 \x01(\t\x12\x12\n\nevent_type\x18\x03 \x01(\t\x12\x36\n\x12received_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x08\x63ontents\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07\x63ontext\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe6\x01\n\x07JobInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x33\n\x0flast_updated_ts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\nparent_ref\x18\x07 \x01(\x0b\x32\x12.oi.papi.ParentRef\x12\x13\n\x0bprovider_id\x18\x08 \x01(\t\"h\n\x14TrackedStatusHistory\x12\x18\n\x10\x64\x61ta_tracking_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12&\n\x02ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd1\x01\n\nTrackedJob\x12&\n\nparent_ref\x18\x01 \x01(\x0b\x32\x12.oi.papi.ParentRef\x12\x1e\n\x04info\x18\x02 \x01(\x0b\x32\x10.oi.papi.JobInfo\x12%\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x15.oi.papi.TrackedEvent\x12\x35\n\x0estatus_history\x18\x04 \x03(\x0b\x32\x1d.oi.papi.TrackedStatusHistory\x12\x1d\n\x05links\x18\x05 \x03(\x0b\x32\x0e.oi.papi.Links\"\"\n DataTrackingGetQueryablesRequest\"P\n!DataTrackingGetQueryablesResponse\x12+\n\nqueryables\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x85\x01\n#DataTrackingTrackedJobSearchRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x13\n\x0b\x66ilter_lang\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x10\n\x08order_by\x18\x04 \x01(\t\"r\n$DataTrackingTrackedJobSearchResponse\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12!\n\x04jobs\x18\x02 \x03(\x0b\x32\x13.oi.papi.TrackedJob2\xf2\x01\n\x0f\x44\x61taTrackingApi\x12g\n\x0eget_queryables\x12).oi.papi.DataTrackingGetQueryablesRequest\x1a*.oi.papi.DataTrackingGetQueryablesResponse\x12v\n\x17get_search_tracked_jobs\x12,.oi.papi.DataTrackingTrackedJobSearchRequest\x1a-.oi.papi.DataTrackingTrackedJobSearchResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_tracking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LINKS']._serialized_start=116
  _globals['_LINKS']._serialized_end=200
  _globals['_PARENTREF']._serialized_start=202
  _globals['_PARENTREF']._serialized_end=257
  _globals['_TRACKEDEVENT']._serialized_start=260
  _globals['_TRACKEDEVENT']._serialized_end=473
  _globals['_JOBINFO']._serialized_start=476
  _globals['_JOBINFO']._serialized_end=706
  _globals['_TRACKEDSTATUSHISTORY']._serialized_start=708
  _globals['_TRACKEDSTATUSHISTORY']._serialized_end=812
  _globals['_TRACKEDJOB']._serialized_start=815
  _globals['_TRACKEDJOB']._serialized_end=1024
  _globals['_DATATRACKINGGETQUERYABLESREQUEST']._serialized_start=1026
  _globals['_DATATRACKINGGETQUERYABLESREQUEST']._serialized_end=1060
  _globals['_DATATRACKINGGETQUERYABLESRESPONSE']._serialized_start=1062
  _globals['_DATATRACKINGGETQUERYABLESRESPONSE']._serialized_end=1142
  _globals['_DATATRACKINGTRACKEDJOBSEARCHREQUEST']._serialized_start=1145
  _globals['_DATATRACKINGTRACKEDJOBSEARCHREQUEST']._serialized_end=1278
  _globals['_DATATRACKINGTRACKEDJOBSEARCHRESPONSE']._serialized_start=1280
  _globals['_DATATRACKINGTRACKEDJOBSEARCHRESPONSE']._serialized_end=1394
  _globals['_DATATRACKINGAPI']._serialized_start=1397
  _globals['_DATATRACKINGAPI']._serialized_end=1639
# @@protoc_insertion_point(module_scope)



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class Bounds(_message.Message):
    __slots__ = ("x_min", "y_min", "x_max", "y_max")
    X_MIN_FIELD_NUMBER: _ClassVar[int]
    Y_MIN_FIELD_NUMBER: _ClassVar[int]
    X_MAX_FIELD_NUMBER: _ClassVar[int]
    Y_MAX_FIELD_NUMBER: _ClassVar[int]
    x_min: float
    y_min: float
    x_max: float
    y_max: float
    def __init__(self, x_min: _Optional[float] = ..., y_min: _Optional[float] = ..., x_max: _Optional[float] = ..., y_max: _Optional[float] = ...) -> None: ...

class TileMatrix(_message.Message):
    __slots__ = ("id", "zoom")
    ID_FIELD_NUMBER: _ClassVar[int]
    ZOOM_FIELD_NUMBER: _ClassVar[int]
    id: str
    zoom: int
    def __init__(self, id: _Optional[str] = ..., zoom: _Optional[int] = ...) -> None: ...

class TileAccessInfo(_message.Message):
    __slots__ = ("url_template", "credentials")
    URL_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    url_template: str
    credentials: _struct_pb2.Struct
    def __init__(self, url_template: _Optional[str] = ..., credentials: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class TileSet(_message.Message):
    __slots__ = ("id", "name", "bounds", "matrices", "tile_access", "from_ts")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    BOUNDS_FIELD_NUMBER: _ClassVar[int]
    MATRICES_FIELD_NUMBER: _ClassVar[int]
    TILE_ACCESS_FIELD_NUMBER: _ClassVar[int]
    FROM_TS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    bounds: Bounds
    matrices: _containers.RepeatedCompositeFieldContainer[TileMatrix]
    tile_access: TileAccessInfo
    from_ts: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., bounds: _Optional[_Union[Bounds, _Mapping]] = ..., matrices: _Optional[_Iterable[_Union[TileMatrix, _Mapping]]] = ..., tile_access: _Optional[_Union[TileAccessInfo, _Mapping]] = ..., from_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class TileSetListRequest(_message.Message):
    __slots__ = ("search_id", "pagination", "tile_ts_from", "tile_ts_to")
    SEARCH_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    TILE_TS_FROM_FIELD_NUMBER: _ClassVar[int]
    TILE_TS_TO_FIELD_NUMBER: _ClassVar[int]
    search_id: str
    pagination: _common_models_pb2.Pagination
    tile_ts_from: _timestamp_pb2.Timestamp
    tile_ts_to: _timestamp_pb2.Timestamp
    def __init__(self, search_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., tile_ts_from: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., tile_ts_to: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class TileSetListResponse(_message.Message):
    __slots__ = ("tile_sets", "pagination")
    TILE_SETS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    tile_sets: _containers.RepeatedCompositeFieldContainer[TileSet]
    pagination: _common_models_pb2.Pagination
    def __init__(self, tile_sets: _Optional[_Iterable[_Union[TileSet, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class Links(_message.Message):
    __slots__ = ("href", "type", "rel", "description", "title")
    HREF_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    REL_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    href: str
    type: str
    rel: str
    description: str
    title: str
    def __init__(self, href: _Optional[str] = ..., type: _Optional[str] = ..., rel: _Optional[str] = ..., description: _Optional[str] = ..., title: _Optional[str] = ...) -> None: ...

class ParentRef(_message.Message):
    __slots__ = ("id", "parent_id", "key")
    ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    id: str
    parent_id: str
    key: str
    def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class TrackedEvent(_message.Message):
    __slots__ = ("id", "data_tracking_id", "event_type", "received_timestamp", "contents", "context")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_TRACKING_ID_FIELD_NUMBER: _ClassVar[int]
    EVENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    RECEIVED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    data_tracking_id: str
    event_type: str
    received_timestamp: _timestamp_pb2.Timestamp
    contents: _struct_pb2.Struct
    context: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., data_tracking_id: _Optional[str] = ..., event_type: _Optional[str] = ..., received_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contents: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., context: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class JobInfo(_message.Message):
    __slots__ = ("id", "name", "status", "user_id", "last_updated_ts", "created_ts", "parent_ref", "provider_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_UPDATED_TS_FIELD_NUMBER: _ClassVar[int]
    CREATED_TS_FIELD_NUMBER: _ClassVar[int]
    PARENT_REF_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    status: str
    user_id: str
    last_updated_ts: _timestamp_pb2.Timestamp
    created_ts: _timestamp_pb2.Timestamp
    parent_ref: ParentRef
    provider_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., status: _Optional[str] = ..., user_id: _Optional[str] = ..., last_updated_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., parent_ref: _Optional[_Union[ParentRef, _Mapping]] = ..., provider_id: _Optional[str] = ...) -> None: ...

class TrackedStatusHistory(_message.Message):
    __slots__ = ("data_tracking_id", "status", "ts")
    DATA_TRACKING_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TS_FIELD_NUMBER: _ClassVar[int]
    data_tracking_id: str
    status: str
    ts: _timestamp_pb2.Timestamp
    def __init__(self, data_tracking_id: _Optional[str] = ..., status: _Optional[str] = ..., ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class TrackedJob(_message.Message):
    __slots__ = ("parent_ref", "info", "events", "status_history", "links")
    PARENT_REF_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    STATUS_HISTORY_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    parent_ref: ParentRef
    info: JobInfo
    events: _containers.RepeatedCompositeFieldContainer[TrackedEvent]
    status_history: _containers.RepeatedCompositeFieldContainer[TrackedStatusHistory]
    links: _containers.RepeatedCompositeFieldContainer[Links]
    def __init__(self, parent_ref: _Optional[_Union[ParentRef, _Mapping]] = ..., info: _Optional[_Union[JobInfo, _Mapping]] = ..., events: _Optional[_Iterable[_Union[TrackedEvent, _Mapping]]] = ..., status_history: _Optional[_Iterable[_Union[TrackedStatusHistory, _Mapping]]] = ..., links: _Optional[_Iterable[_Union[Links, _Mapping]]] = ...) -> None: ...

class DataTrackingGetQueryablesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DataTrackingGetQueryablesResponse(_message.Message):
    __slots__ = ("queryables",)
    QUERYABLES_FIELD_NUMBER: _ClassVar[int]
    queryables: _struct_pb2.Struct
    def __init__(self, queryables: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DataTrackingTrackedJobSearchRequest(_message.Message):
    __slots__ = ("pagination", "filter_lang", "filter", "order_by")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    FILTER_LANG_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    filter_lang: str
    filter: str
    order_by: str
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., filter_lang: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class DataTrackingTrackedJobSearchResponse(_message.Message):
    __slots__ = ("pagination", "jobs")
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    JOBS_FIELD_NUMBER: _ClassVar[int]
    pagination: _common_models_pb2.Pagination
    jobs: _containers.RepeatedCompositeFieldContainer[TrackedJob]
    def __init__(self, pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ..., jobs: _Optional[_Iterable[_Union[TrackedJob, _Mapping]]] = ...) -> None: ...



import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor

class ProjectCollaborator(_message.Message):
    __slots__ = ("user_id", "role", "customer_id", "name")
    class ProjectRole(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_PROJECT_ROLE: _ClassVar[ProjectCollaborator.ProjectRole]
        CREATOR: _ClassVar[ProjectCollaborator.ProjectRole]
        COLLABORATOR: _ClassVar[ProjectCollaborator.ProjectRole]
        VIEWER: _ClassVar[ProjectCollaborator.ProjectRole]
    UNKNOWN_PROJECT_ROLE: ProjectCollaborator.ProjectRole
    CREATOR: ProjectCollaborator.ProjectRole
    COLLABORATOR: ProjectCollaborator.ProjectRole
    VIEWER: ProjectCollaborator.ProjectRole
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    role: ProjectCollaborator.ProjectRole
    customer_id: str
    name: str
    def __init__(self, user_id: _Optional[str] = ..., role: _Optional[_Union[ProjectCollaborator.ProjectRole, str]] = ..., customer_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class ProjectCollaboratorGetRequest(_message.Message):
    __slots__ = ("project_id",)
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    def __init__(self, project_id: _Optional[str] = ...) -> None: ...

class ProjectCollaboratorGetResponse(_message.Message):
    __slots__ = ("status_code", "project_collaborators")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    PROJECT_COLLABORATORS_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    project_collaborators: _containers.RepeatedCompositeFieldContainer[ProjectCollaborator]
    def __init__(self, status_code: _Optional[int] = ..., project_collaborators: _Optional[_Iterable[_Union[ProjectCollaborator, _Mapping]]] = ...) -> None: ...

class ProjectCollaboratorUpdateRequest(_message.Message):
    __slots__ = ("project_id", "project_collaborators")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_COLLABORATORS_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    project_collaborators: _containers.RepeatedCompositeFieldContainer[ProjectCollaborator]
    def __init__(self, project_id: _Optional[str] = ..., project_collaborators: _Optional[_Iterable[_Union[ProjectCollaborator, _Mapping]]] = ...) -> None: ...

class ProjectCollaboratorUpdateResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class ProjectCollaboratorDeleteRequest(_message.Message):
    __slots__ = ("project_id", "user_ids")
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    project_id: str
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, project_id: _Optional[str] = ..., user_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class ProjectCollaboratorDeleteResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
import order_recommendation_pb2 as _order_recommendation_pb2
import common_models_pb2 as _common_models_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from order_recommendation_pb2 import OrderRecommendation as OrderRecommendation
from order_recommendation_pb2 import OrderRecommendationCreateRequest as OrderRecommendationCreateRequest
from order_recommendation_pb2 import OrderRecommendationCreateResponse as OrderRecommendationCreateResponse
from order_recommendation_pb2 import OrderRecommendationUpdateRequest as OrderRecommendationUpdateRequest
from order_recommendation_pb2 import OrderRecommendationUpdateResponse as OrderRecommendationUpdateResponse
from order_recommendation_pb2 import OrderRecommendationDeleteRequest as OrderRecommendationDeleteRequest
from order_recommendation_pb2 import OrderRecommendationDeleteResponse as OrderRecommendationDeleteResponse
from order_recommendation_pb2 import OrderType as OrderType
from common_models_pb2 import Pagination as Pagination

DESCRIPTOR: _descriptor.FileDescriptor
UNSPECIFIED: _order_recommendation_pb2.OrderType
ARCHIVE: _order_recommendation_pb2.OrderType
TASKING: _order_recommendation_pb2.OrderType

class OrderState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNKNOWN: _ClassVar[OrderState]
    CREATED: _ClassVar[OrderState]
    APPROVED: _ClassVar[OrderState]
    QUEUED: _ClassVar[OrderState]
    PROCESSING: _ClassVar[OrderState]
    ORDERED: _ClassVar[OrderState]
    CANCELLED: _ClassVar[OrderState]
    DELIVERED: _ClassVar[OrderState]
    FAILED: _ClassVar[OrderState]
    PENDING_APPROVAL: _ClassVar[OrderState]
    SUBMITTED: _ClassVar[OrderState]
UNKNOWN: OrderState
CREATED: OrderState
APPROVED: OrderState
QUEUED: OrderState
PROCESSING: OrderState
ORDERED: OrderState
CANCELLED: OrderState
DELIVERED: OrderState
FAILED: OrderState
PENDING_APPROVAL: OrderState
SUBMITTED: OrderState

class Item(_message.Message):
    __slots__ = ("id", "scene_id", "target_geom", "item_metadata")
    ID_FIELD_NUMBER: _ClassVar[int]
    SCENE_ID_FIELD_NUMBER: _ClassVar[int]
    TARGET_GEOM_FIELD_NUMBER: _ClassVar[int]
    ITEM_METADATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    scene_id: str
    target_geom: bytes
    item_metadata: _struct_pb2.Struct
    def __init__(self, id: _Optional[str] = ..., scene_id: _Optional[str] = ..., target_geom: _Optional[bytes] = ..., item_metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class Order(_message.Message):
    __slots__ = ("id", "data_source_id", "items", "product_spec_name", "state", "details", "url", "metadata", "creator", "created_on", "updated_on", "approved_by", "approval_comment", "recommendations")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_SPEC_NAME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    DETAILS_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    UPDATED_ON_FIELD_NUMBER: _ClassVar[int]
    APPROVED_BY_FIELD_NUMBER: _ClassVar[int]
    APPROVAL_COMMENT_FIELD_NUMBER: _ClassVar[int]
    RECOMMENDATIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    data_source_id: str
    items: _containers.RepeatedCompositeFieldContainer[Item]
    product_spec_name: str
    state: OrderState
    details: str
    url: str
    metadata: _struct_pb2.Struct
    creator: str
    created_on: _timestamp_pb2.Timestamp
    updated_on: _timestamp_pb2.Timestamp
    approved_by: str
    approval_comment: str
    recommendations: _containers.RepeatedCompositeFieldContainer[_order_recommendation_pb2.OrderRecommendation]
    def __init__(self, id: _Optional[str] = ..., data_source_id: _Optional[str] = ..., items: _Optional[_Iterable[_Union[Item, _Mapping]]] = ..., product_spec_name: _Optional[str] = ..., state: _Optional[_Union[OrderState, str]] = ..., details: _Optional[str] = ..., url: _Optional[str] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., creator: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., approved_by: _Optional[str] = ..., approval_comment: _Optional[str] = ..., recommendations: _Optional[_Iterable[_Union[_order_recommendation_pb2.OrderRecommendation, _Mapping]]] = ...) -> None: ...

class OrderListRequest(_message.Message):
    __slots__ = ("states", "data_source_ids", "provider_ids", "analysis_computation_ids", "algorithm_computation_ids", "pagination")
    STATES_FIELD_NUMBER: _ClassVar[int]
    DATA_SOURCE_IDS_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_IDS_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATION_IDS_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_COMPUTATION_IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    states: _containers.RepeatedScalarFieldContainer[OrderState]
    data_source_ids: _containers.RepeatedScalarFieldContainer[str]
    provider_ids: _containers.RepeatedScalarFieldContainer[str]
    analysis_computation_ids: _containers.RepeatedScalarFieldContainer[str]
    algorithm_computation_ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2.Pagination
    def __init__(self, states: _Optional[_Iterable[_Union[OrderState, str]]] = ..., data_source_ids: _Optional[_Iterable[str]] = ..., provider_ids: _Optional[_Iterable[str]] = ..., analysis_computation_ids: _Optional[_Iterable[str]] = ..., algorithm_computation_ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class OrderListResponse(_message.Message):
    __slots__ = ("status_code", "orders", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ORDERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    orders: _containers.RepeatedCompositeFieldContainer[Order]
    pagination: _common_models_pb2.Pagination
    def __init__(self, status_code: _Optional[int] = ..., orders: _Optional[_Iterable[_Union[Order, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2.Pagination, _Mapping]] = ...) -> None: ...

class OrderGetRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class OrderGetResponse(_message.Message):
    __slots__ = ("status_code", "order")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    order: Order
    def __init__(self, status_code: _Optional[int] = ..., order: _Optional[_Union[Order, _Mapping]] = ...) -> None: ...

class OrderApproveRequest(_message.Message):
    __slots__ = ("id", "comment")
    ID_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    comment: str
    def __init__(self, id: _Optional[str] = ..., comment: _Optional[str] = ...) -> None: ...

class OrderApproveResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class OrderCreateRequest(_message.Message):
    __slots__ = ("data_source_id", "product_spec_name", "metadata", "items")
    DATA_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_SPEC_NAME_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    data_source_id: str
    product_spec_name: str
    metadata: _struct_pb2.Struct
    items: _containers.RepeatedCompositeFieldContainer[Item]
    def __init__(self, data_source_id: _Optional[str] = ..., product_spec_name: _Optional[str] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., items: _Optional[_Iterable[_Union[Item, _Mapping]]] = ...) -> None: ...

class OrderCreateResponse(_message.Message):
    __slots__ = ("status_code", "order")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    order: Order
    def __init__(self, status_code: _Optional[int] = ..., order: _Optional[_Union[Order, _Mapping]] = ...) -> None: ...

class OrderCancelRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class OrderCancelResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: data_source.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'data_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import data_type_pb2 as data__type__pb2

from terrascope_api.models.data_type_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64\x61ta_source.proto\x12\x07oi.papi\x1a\x0f\x64\x61ta_type.proto\"\xc0\x01\n\nDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12%\n\ndata_types\x18\x04 \x03(\x0b\x32\x11.oi.papi.DataType\x12\x1c\n\x14\x64\x65livery_lag_seconds\x18\x05 \x01(\x04\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\x12\x11\n\tindicator\x18\x07 \x01(\t\x12\x15\n\rdata_explorer\x18\x08 \x01(\x08\"#\n\x14\x44\x61taSourceGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"W\n\x15\x44\x61taSourceGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x13.oi.papi.DataSource\",\n\x15\x44\x61taSourceListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\"X\n\x16\x44\x61taSourceListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32\x13.oi.papi.DataSource2\x9e\x01\n\rDataSourceAPI\x12\x44\n\x03get\x12\x1d.oi.papi.DataSourceGetRequest\x1a\x1e.oi.papi.DataSourceGetResponse\x12G\n\x04list\x12\x1e.oi.papi.DataSourceListRequest\x1a\x1f.oi.papi.DataSourceListResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DATASOURCE']._serialized_start=48
  _globals['_DATASOURCE']._serialized_end=240
  _globals['_DATASOURCEGETREQUEST']._serialized_start=242
  _globals['_DATASOURCEGETREQUEST']._serialized_end=277
  _globals['_DATASOURCEGETRESPONSE']._serialized_start=279
  _globals['_DATASOURCEGETRESPONSE']._serialized_end=366
  _globals['_DATASOURCELISTREQUEST']._serialized_start=368
  _globals['_DATASOURCELISTREQUEST']._serialized_end=412
  _globals['_DATASOURCELISTRESPONSE']._serialized_start=414
  _globals['_DATASOURCELISTRESPONSE']._serialized_end=502
  _globals['_DATASOURCEAPI']._serialized_start=505
  _globals['_DATASOURCEAPI']._serialized_end=663
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: aoi_catalog.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'aoi_catalog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2
try:
  common__models__pb2 = aoi__collection__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__collection__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.aoi_collection_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61oi_catalog.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\x1a\x14\x61oi_collection.proto\"\x85\x02\n\x08\x41OIStats\x12+\n\ncategories\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\tcountries\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12(\n\x07sources\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\'\n\x06states\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12&\n\x05types\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xe6\x01\n\x12\x41OIStatsGetRequest\x12\x0c\n\x04\x62\x62ox\x18\x01 \x03(\x01\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12\x10\n\x08min_area\x18\x08 \x01(\x01\x12\x10\n\x08max_area\x18\t \x01(\x01\x12\x0f\n\x07sources\x18\n \x03(\t\x12*\n\x0clibrary_type\x18\x0b \x01(\x0e\x32\x14.oi.papi.LibraryType\"P\n\x13\x41OIStatsGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\taoi_stats\x18\x02 \x01(\x0b\x32\x11.oi.papi.AOIStats\"6\n\nAOICluster\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0c\n\x04long\x18\x02 \x01(\x01\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"\xe8\x01\n\x14\x41OIClusterGetRequest\x12\x0c\n\x04\x62\x62ox\x18\x01 \x03(\x01\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x13\n\x0bsearch_text\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12\x10\n\x08min_area\x18\x08 \x01(\x01\x12\x10\n\x08max_area\x18\t \x01(\x01\x12\x0f\n\x07sources\x18\n \x03(\t\x12*\n\x0clibrary_type\x18\x0b \x01(\x0e\x32\x14.oi.papi.LibraryType\"W\n\x15\x41OIClusterGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\x0c\x61oi_clusters\x18\x02 \x03(\x0b\x32\x13.oi.papi.AOICluster\"\'\n\x14\x41OICatalogAddRequest\x12\x0f\n\x07\x61oi_ids\x18\x01 \x03(\t\",\n\x15\x41OICatalogAddResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"*\n\x17\x41OICatalogDeleteRequest\x12\x0f\n\x07\x61oi_ids\x18\x01 \x03(\t\"/\n\x18\x41OICatalogDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"$\n\"AOICatalogGetPrivateCatalogRequest\"V\n#AOICatalogGetPrivateCatalogResponse\x12/\n\x0fuser_collection\x18\x01 \x01(\x0b\x32\x16.oi.papi.AOICollection*&\n\x0bLibraryType\x12\x0b\n\x07PRIVATE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x32\xe0\x03\n\rAOICatalogApi\x12J\n\rget_aoi_stats\x12\x1b.oi.papi.AOIStatsGetRequest\x1a\x1c.oi.papi.AOIStatsGetResponse\x12Q\n\x10get_aoi_clusters\x12\x1d.oi.papi.AOIClusterGetRequest\x1a\x1e.oi.papi.AOIClusterGetResponse\x12S\n\x12\x61\x64\x64_aoi_to_catalog\x12\x1d.oi.papi.AOICatalogAddRequest\x1a\x1e.oi.papi.AOICatalogAddResponse\x12^\n\x17\x64\x65lete_aoi_from_catalog\x12 .oi.papi.AOICatalogDeleteRequest\x1a!.oi.papi.AOICatalogDeleteResponse\x12{\n\x1eget_private_catalog_collection\x12+.oi.papi.AOICatalogGetPrivateCatalogRequest\x1a,.oi.papi.AOICatalogGetPrivateCatalogResponseP\x01P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_catalog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LIBRARYTYPE']._serialized_start=1368
  _globals['_LIBRARYTYPE']._serialized_end=1406
  _globals['_AOISTATS']._serialized_start=104
  _globals['_AOISTATS']._serialized_end=365
  _globals['_AOISTATSGETREQUEST']._serialized_start=368
  _globals['_AOISTATSGETREQUEST']._serialized_end=598
  _globals['_AOISTATSGETRESPONSE']._serialized_start=600
  _globals['_AOISTATSGETRESPONSE']._serialized_end=680
  _globals['_AOICLUSTER']._serialized_start=682
  _globals['_AOICLUSTER']._serialized_end=736
  _globals['_AOICLUSTERGETREQUEST']._serialized_start=739
  _globals['_AOICLUSTERGETREQUEST']._serialized_end=971
  _globals['_AOICLUSTERGETRESPONSE']._serialized_start=973
  _globals['_AOICLUSTERGETRESPONSE']._serialized_end=1060
  _globals['_AOICATALOGADDREQUEST']._serialized_start=1062
  _globals['_AOICATALOGADDREQUEST']._serialized_end=1101
  _globals['_AOICATALOGADDRESPONSE']._serialized_start=1103
  _globals['_AOICATALOGADDRESPONSE']._serialized_end=1147
  _globals['_AOICATALOGDELETEREQUEST']._serialized_start=1149
  _globals['_AOICATALOGDELETEREQUEST']._serialized_end=1191
  _globals['_AOICATALOGDELETERESPONSE']._serialized_start=1193
  _globals['_AOICATALOGDELETERESPONSE']._serialized_end=1240
  _globals['_AOICATALOGGETPRIVATECATALOGREQUEST']._serialized_start=1242
  _globals['_AOICATALOGGETPRIVATECATALOGREQUEST']._serialized_end=1278
  _globals['_AOICATALOGGETPRIVATECATALOGRESPONSE']._serialized_start=1280
  _globals['_AOICATALOGGETPRIVATECATALOGRESPONSE']._serialized_end=1366
  _globals['_AOICATALOGAPI']._serialized_start=1409
  _globals['_AOICATALOGAPI']._serialized_end=1889
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
import common_models_pb2 as _common_models_pb2
import analysis_pb2 as _analysis_pb2
import common_models_pb2 as _common_models_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
from common_models_pb2 import Pagination as Pagination
from analysis_pb2 import AnalysisAlgorithmNode as AnalysisAlgorithmNode
from analysis_pb2 import AnalysisCreateRequest as AnalysisCreateRequest
from analysis_pb2 import AnalysisCreateResponse as AnalysisCreateResponse
from analysis_pb2 import AnalysisAlgorithmConfigNode as AnalysisAlgorithmConfigNode
from analysis_pb2 import AnalysisGetRequest as AnalysisGetRequest
from analysis_pb2 import Analysis as Analysis
from analysis_pb2 import AnalysisGetResponse as AnalysisGetResponse
from analysis_pb2 import AnalysisListRequest as AnalysisListRequest
from analysis_pb2 import AnalysisListResponse as AnalysisListResponse

DESCRIPTOR: _descriptor.FileDescriptor

class AnalysisComputationCreateRequest(_message.Message):
    __slots__ = ("analysis_config_id", "toi_id", "aoi_collection_id")
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    analysis_config_id: str
    toi_id: str
    aoi_collection_id: str
    def __init__(self, analysis_config_id: _Optional[str] = ..., toi_id: _Optional[str] = ..., aoi_collection_id: _Optional[str] = ...) -> None: ...

class AnalysisComputationCreateResponse(_message.Message):
    __slots__ = ("status_code", "analysis_computation")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_computation: AnalysisComputation
    def __init__(self, status_code: _Optional[int] = ..., analysis_computation: _Optional[_Union[AnalysisComputation, _Mapping]] = ...) -> None: ...

class AnalysisComputationRunRequest(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...

class AnalysisComputationRunResponse(_message.Message):
    __slots__ = ("status_code",)
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    def __init__(self, status_code: _Optional[int] = ...) -> None: ...

class AnalysisComputationGetRequest(_message.Message):
    __slots__ = ("ids", "pagination")
    IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[str]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, ids: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisComputationNode(_message.Message):
    __slots__ = ("name", "computation_id", "children", "has_results")
    NAME_FIELD_NUMBER: _ClassVar[int]
    COMPUTATION_ID_FIELD_NUMBER: _ClassVar[int]
    CHILDREN_FIELD_NUMBER: _ClassVar[int]
    HAS_RESULTS_FIELD_NUMBER: _ClassVar[int]
    name: str
    computation_id: str
    children: _containers.RepeatedScalarFieldContainer[str]
    has_results: bool
    def __init__(self, name: _Optional[str] = ..., computation_id: _Optional[str] = ..., children: _Optional[_Iterable[str]] = ..., has_results: bool = ...) -> None: ...

class AnalysisComputation(_message.Message):
    __slots__ = ("id", "analysis_id", "toi_id", "aoi_collection_id", "analysis_config_id", "submitted_on", "state", "computation_nodes", "progress")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATE: _ClassVar[AnalysisComputation.State]
        NOT_STARTED: _ClassVar[AnalysisComputation.State]
        IN_PROGRESS: _ClassVar[AnalysisComputation.State]
        PAUSED: _ClassVar[AnalysisComputation.State]
        COMPLETE: _ClassVar[AnalysisComputation.State]
    UNKNOWN_STATE: AnalysisComputation.State
    NOT_STARTED: AnalysisComputation.State
    IN_PROGRESS: AnalysisComputation.State
    PAUSED: AnalysisComputation.State
    COMPLETE: AnalysisComputation.State
    class Progress(_message.Message):
        __slots__ = ("running", "succeeded", "failed")
        RUNNING_FIELD_NUMBER: _ClassVar[int]
        SUCCEEDED_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        running: float
        succeeded: float
        failed: float
        def __init__(self, running: _Optional[float] = ..., succeeded: _Optional[float] = ..., failed: _Optional[float] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_ID_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTED_ON_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    COMPUTATION_NODES_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    id: str
    analysis_id: str
    toi_id: str
    aoi_collection_id: str
    analysis_config_id: str
    submitted_on: _timestamp_pb2.Timestamp
    state: AnalysisComputation.State
    computation_nodes: _containers.RepeatedCompositeFieldContainer[AnalysisComputationNode]
    progress: AnalysisComputation.Progress
    def __init__(self, id: _Optional[str] = ..., analysis_id: _Optional[str] = ..., toi_id: _Optional[str] = ..., aoi_collection_id: _Optional[str] = ..., analysis_config_id: _Optional[str] = ..., submitted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[AnalysisComputation.State, str]] = ..., computation_nodes: _Optional[_Iterable[_Union[AnalysisComputationNode, _Mapping]]] = ..., progress: _Optional[_Union[AnalysisComputation.Progress, _Mapping]] = ...) -> None: ...

class AnalysisComputationGetResponse(_message.Message):
    __slots__ = ("status_code", "analysis_computations", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_computations: _containers.RepeatedCompositeFieldContainer[AnalysisComputation]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analysis_computations: _Optional[_Iterable[_Union[AnalysisComputation, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisComputationListRequest(_message.Message):
    __slots__ = ("state", "status", "min_submitted_on", "max_submitted_on", "analysis_config_id", "toi_id", "aoi_collection_id", "analysis_id", "pagination")
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MIN_SUBMITTED_ON_FIELD_NUMBER: _ClassVar[int]
    MAX_SUBMITTED_ON_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_CONFIG_ID_FIELD_NUMBER: _ClassVar[int]
    TOI_ID_FIELD_NUMBER: _ClassVar[int]
    AOI_COLLECTION_ID_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    state: str
    status: str
    min_submitted_on: _timestamp_pb2.Timestamp
    max_submitted_on: _timestamp_pb2.Timestamp
    analysis_config_id: str
    toi_id: str
    aoi_collection_id: str
    analysis_id: str
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, state: _Optional[str] = ..., status: _Optional[str] = ..., min_submitted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., max_submitted_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., analysis_config_id: _Optional[str] = ..., toi_id: _Optional[str] = ..., aoi_collection_id: _Optional[str] = ..., analysis_id: _Optional[str] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...

class AnalysisComputationListResponse(_message.Message):
    __slots__ = ("status_code", "analysis_computations", "pagination")
    STATUS_CODE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_COMPUTATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    status_code: int
    analysis_computations: _containers.RepeatedCompositeFieldContainer[AnalysisComputation]
    pagination: _common_models_pb2_1.Pagination
    def __init__(self, status_code: _Optional[int] = ..., analysis_computations: _Optional[_Iterable[_Union[AnalysisComputation, _Mapping]]] = ..., pagination: _Optional[_Union[_common_models_pb2_1.Pagination, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import project_aoi_pb2 as project__aoi__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in project_aoi_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ProjectAOIApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/create',
                request_serializer=project__aoi__pb2.ProjectAOICreateRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOICreateResponse.FromString,
                _registered_method=True)
        self.upload = channel.stream_unary(
                '/oi.papi.ProjectAOIApi/upload',
                request_serializer=project__aoi__pb2.ProjectAOIUploadRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIFileUploadResponse.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/delete',
                request_serializer=project__aoi__pb2.ProjectAOIDeleteRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIDeleteResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/get',
                request_serializer=project__aoi__pb2.ProjectAOIGetRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIGetResponse.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/oi.papi.ProjectAOIApi/update',
                request_serializer=project__aoi__pb2.ProjectAOIUpdateRequest.SerializeToString,
                response_deserializer=project__aoi__pb2.ProjectAOIUpdateResponse.FromString,
                _registered_method=True)


class ProjectAOIApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        Create Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def upload(self, request_iterator, context):
        """
        Upload AOIs to Project
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        Delete Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        Update Project AOIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectAOIApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=project__aoi__pb2.ProjectAOICreateRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOICreateResponse.SerializeToString,
            ),
            'upload': grpc.stream_unary_rpc_method_handler(
                    servicer.upload,
                    request_deserializer=project__aoi__pb2.ProjectAOIUploadRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIFileUploadResponse.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=project__aoi__pb2.ProjectAOIDeleteRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIDeleteResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=project__aoi__pb2.ProjectAOIGetRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIGetResponse.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=project__aoi__pb2.ProjectAOIUpdateRequest.FromString,
                    response_serializer=project__aoi__pb2.ProjectAOIUpdateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.ProjectAOIApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.ProjectAOIApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectAOIApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/create',
            project__aoi__pb2.ProjectAOICreateRequest.SerializeToString,
            project__aoi__pb2.ProjectAOICreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def upload(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/oi.papi.ProjectAOIApi/upload',
            project__aoi__pb2.ProjectAOIUploadRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIFileUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/delete',
            project__aoi__pb2.ProjectAOIDeleteRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/get',
            project__aoi__pb2.ProjectAOIGetRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectAOIApi/update',
            project__aoi__pb2.ProjectAOIUpdateRequest.SerializeToString,
            project__aoi__pb2.ProjectAOIUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
